@@ -13,8 +13,6 @@
 
 import logging
 
-from openstack import connection
-from openstack import profile
 from osc_lib import utils
 
 from openstackclient.i18n import _
@@ -33,18 +31,17 @@ API_VERSIONS = {
 
 def make_client(instance):
     """Returns a network proxy"""
-    prof = profile.Profile()
-    prof.set_region(API_NAME, instance.region_name)
-    prof.set_version(API_NAME, instance._api_version[API_NAME])
-    prof.set_interface(API_NAME, instance.interface)
-    conn = connection.Connection(authenticator=instance.session.auth,
-                                 verify=instance.session.verify,
-                                 cert=instance.session.cert,
-                                 profile=prof)
-    LOG.debug('Connection: %s', conn)
-    LOG.debug('Network client initialized using OpenStack SDK: %s',
-              conn.network)
-    return conn.network
+    # NOTE(dtroyer): As of osc-lib 1.8.0 and OpenStackSDK 0.10.0 the
+    #                old Profile interface and separate client creation
+    #                for each API that uses the SDK is unnecessary.  This
+    #                callback remains as a remnant of the original plugin
+    #                interface and to avoid the code churn of changing all
+    #                of the existing references.
+    LOG.debug(
+        'Network client initialized using OpenStack SDK: %s',
+        instance.sdk_connection.network,
+    )
+    return instance.sdk_connection.network
 
 
 def build_option_parser(parser):
