@@ -21,8 +21,6 @@ from osc_lib import utils
 
 from openstackclient.i18n import _
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
-
 
 RULE_TYPE_BANDWIDTH_LIMIT = 'bandwidth-limit'
 RULE_TYPE_DSCP_MARKING = 'dscp-marking'
@@ -51,7 +49,7 @@ def _get_columns(item):
     column_map = {
         'tenant_id': 'project_id',
     }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    return utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
 def _check_type_parameters(attrs, type, is_create):
