@@ -26,14 +26,13 @@ from osc_lib import utils
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
 
 
 LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, {})
+    return utils.get_osc_show_columns_for_sdk_resource(item, {})
 
 
 def _get_ranges(item):
