@@ -23,10 +23,8 @@ from osc_lib import utils
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
 from openstackclient.network import utils as network_utils
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -76,7 +74,7 @@ def _get_columns(item):
     column_map = {
         'tenant_id': 'project_id',
     }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    return utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
 def _convert_to_lowercase(string):
