@@ -27,8 +27,6 @@ from osc_lib.utils import tags as _tag
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
-
 
 LOG = logging.getLogger(__name__)
 
@@ -143,7 +141,7 @@ def _get_columns(item):
     }
     # Do not show this column when displaying a subnet
     invisible_columns = ['use_default_subnet_pool', 'prefix_length']
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(
+    return utils.get_osc_show_columns_for_sdk_resource(
         item,
         column_map,
         invisible_columns=invisible_columns
