@@ -15,50 +15,47 @@ import uuid
 
 import fixtures
 
-from openstackclient.tests.functional import base
+from openstackclient.tests.functional.image import base
 
 
-class ImageTests(base.TestCase):
-    """Functional tests for image. """
-
-    NAME = uuid.uuid4().hex
-    OTHER_NAME = uuid.uuid4().hex
-
-    @classmethod
-    def setUpClass(cls):
-        super(ImageTests, cls).setUpClass()
-        json_output = json.loads(cls.openstack(
-            '--os-image-api-version 1 '
-            'image create -f json ' +
-            cls.NAME
-        ))
-        cls.image_id = json_output["id"]
-        cls.assertOutput(cls.NAME, json_output['name'])
-
-    @classmethod
-    def tearDownClass(cls):
-        try:
-            cls.openstack(
-                '--os-image-api-version 1 '
-                'image delete ' +
-                cls.image_id
-            )
-        finally:
-            super(ImageTests, cls).tearDownClass()
+class ImageTests(base.BaseImageTests):
+    """Functional tests for Image commands"""
 
     def setUp(self):
         super(ImageTests, self).setUp()
+        if not self.haz_v1_api:
+            self.skipTest('No Image v1 API present')
+
+        self.name = uuid.uuid4().hex
+        json_output = json.loads(self.openstack(
+            '--os-image-api-version 1 '
+            'image create -f json ' +
+            self.name
+        ))
+        self.image_id = json_output["id"]
+        self.assertOutput(self.name, json_output['name'])
+
         ver_fixture = fixtures.EnvironmentVariable(
             'OS_IMAGE_API_VERSION', '1'
         )
         self.useFixture(ver_fixture)
 
+    def tearDown(self):
+        try:
+            self.openstack(
+                '--os-image-api-version 1 '
+                'image delete ' +
+                self.image_id
+            )
+        finally:
+            super(ImageTests, self).tearDown()
+
     def test_image_list(self):
         json_output = json.loads(self.openstack(
             'image list -f json '
         ))
         self.assertIn(
-            self.NAME,
+            self.name,
             [img['Name'] for img in json_output]
         )
 
@@ -72,11 +69,11 @@ class ImageTests(base.TestCase):
             '--min-ram 5 ' +
             '--disk-format qcow2 ' +
             '--public ' +
-            self.NAME
+            self.name
         )
         json_output = json.loads(self.openstack(
             'image show -f json ' +
-            self.NAME
+            self.name
         ))
         self.assertEqual(
             4,
@@ -100,13 +97,13 @@ class ImageTests(base.TestCase):
             '--property a=b ' +
             '--property c=d ' +
             '--public ' +
-            self.NAME
+            self.name
         )
         json_output = json.loads(self.openstack(
             'image show -f json ' +
-            self.NAME
+            self.name
         ))
         self.assertEqual(
-            "a='b', c='d'",
+            {'a': 'b', 'c': 'd'},
             json_output["properties"],
         )
